pm4py.statistics.eventually\_follows package
============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.statistics.eventually_follows.log
   pm4py.statistics.eventually_follows.pandas

Module contents
---------------

.. automodule:: pm4py.statistics.eventually_follows
   :members:
   :undoc-members:
   :show-inheritance:
